@@ -6,7 +6,7 @@ require 'spec_helper'
 describe 'designate::api' do
 
   let :pre_condition do
-    "class { '::designate::keystone::authtoken':
+    "class { 'designate::keystone::authtoken':
       password => 'a_big_secret',
     }"
   end
@@ -33,12 +33,11 @@ describe 'designate::api' do
 
       it 'configures designate-api with default parameters' do
         is_expected.to contain_designate_config('service:api/auth_strategy').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('service:api/enable_api_v1').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enable_api_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enable_api_admin').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/api_base_uri').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/listen').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('service:api/workers').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_designate_config('service:api/workers').with_value(8)
         is_expected.to contain_designate_config('service:api/threads').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enable_host_header').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/max_header_line').with_value('<SERVICE DEFAULT>')
@@ -47,7 +46,6 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/default_limit_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/max_limit_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/pecan_debug').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('service:api/enabled_extensions_v1').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_designate__keystone__authtoken('designate_config')
@@ -58,7 +56,6 @@ describe 'designate::api' do
       before do
         params.merge!({
           :auth_strategy                 => 'noauth',
-          :enable_api_v1                 => false,
           :enable_api_v2                 => true,
           :enable_api_admin              => true,
           :api_base_uri                  => 'http://myhost.es:9001/',
@@ -72,7 +69,6 @@ describe 'designate::api' do
           :default_limit_v2              => '25',
           :max_limit_v2                  => '1500',
           :pecan_debug                   => true,
-          :enabled_extensions_v1         => 'diagnostics,quotas,reports,sync,touch',
           :enabled_extensions_v2         => 'experimental',
           :enabled_extensions_admin      => 'reports,quotas,counts,tenants,target_sync',
         })
@@ -80,7 +76,6 @@ describe 'designate::api' do
 
       it 'configure service_api' do
         is_expected.to contain_designate_config('service:api/auth_strategy').with_value(params[:auth_strategy])
-        is_expected.to contain_designate_config('service:api/enable_api_v1').with_value(params[:enable_api_v1])
         is_expected.to contain_designate_config('service:api/enable_api_v2').with_value(params[:enable_api_v2])
         is_expected.to contain_designate_config('service:api/enable_api_admin').with_value(params[:enable_api_admin])
         is_expected.to contain_designate_config('service:api/api_base_uri').with_value(params[:api_base_uri])
@@ -94,7 +89,6 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/default_limit_v2').with_value(params[:default_limit_v2])
         is_expected.to contain_designate_config('service:api/max_limit_v2').with_value(params[:max_limit_v2])
         is_expected.to contain_designate_config('service:api/pecan_debug').with_value(params[:pecan_debug])
-        is_expected.to contain_designate_config('service:api/enabled_extensions_v1').with_value(params[:enabled_extensions_v1])
         is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value(params[:enabled_extensions_v2])
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value(params[:enabled_extensions_admin])
       end
@@ -120,7 +114,7 @@ describe 'designate::api' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({ :os_workers => 8 }))
       end
 
       let(:platform_params) do
